@@ -10,6 +10,7 @@ class Player(object):
 
     process_name = None # used for pidof
     friendly_name = None # used for display in help
+    sort_order = 0 # set lower for higher priority
 
     def is_running(self):
         """
@@ -117,3 +118,7 @@ class Player(object):
         Shows OSD (on screen display).
         """
         raise NotImplementedError
+
+    def __lt__(self, other):
+        # This is needed to stop errors on Python 3
+        return self.sort_order < other.sort_order
