@@ -2,6 +2,11 @@ from playerdo.backends.base import Player
 from playerdo.utils import process_stdout, process_retval
 
 
+# Convoluted expressions fpr Python 2/3 compat
+STATE_STOP = "State: STOP".encode('ascii')
+STATE_PAUSE = "State: PAUSE".encode('ascii')
+
+
 class Moc(Player):
 
     process_name = "mocp"
@@ -9,11 +14,11 @@ class Moc(Player):
 
     def is_stopped(self):
         info = process_stdout(["mocp", "-i"])
-        return "State: STOP" in info
+        return STATE_STOP in info
 
     def is_paused(self):
         info = process_stdout(["mocp", "-i"])
-        return "State: PAUSE" in info
+        return STATE_PAUSE in info
 
     def play(self):
         process_retval(["mocp", "--play"])
