@@ -1,5 +1,4 @@
 import subprocess
-import dbus
 
 
 # Helpers for process output
@@ -29,7 +28,7 @@ def process_retval(args, input=None):
 
 def process_true(args, input=None):
     """
-    Executes a process and rturns true if the process has a zero return code
+    Executes a process and returns True if the process has a zero return code
     """
     return process_retval(args, input=input) == 0
 
@@ -45,16 +44,37 @@ class DBusObject(object):
     to be specified once.
     """
 
-    def __init__(self, bus_name, object_name):
+    def __init__(self, bus_name, object_name, interface=None):
+        import dbus
         bus = dbus.SessionBus()
         self._bus = bus
-        self._obj = bus.get_object(bus_name, object_name)
+        obj = bus.get_object(bus_name, object_name)
+        if interface is not None:
+            obj = dbus.Interface(obj, interface)
+        self._obj = obj
 
     def __getattr__(self, name):
         def f(*args, **kwargs):
             return getattr(self._obj, name)(*args, **kwargs)
         return f
 
+class DBusProperties(object):
+    # I can't find a decent way of getting properties in python dbus, this is my
+    # wrapper.
+
+    def __init__(self, bus_name, object_name, interface_name):
+        # dbus_object
+        import dbus
+        bus = dbus.SessionBus()
+        self.dbus_object = bus.get_object(bus_name, object_name)
+        self.interface_name = interface_name
+        self.dbus_props = dbus.Interface(self.dbus_object, "org.freedesktop.DBus.Properties")
+
+    def get(self, property_name):
+        return self.dbus_props.Get(self.interface_name, property_name)
+
+    def set(self, property_name, value):
+        self.dbus_props.Set(self.interface_name, property_name, value)
 
 # Misc helpers
 def catch_unimplemented(c, replacement=None):
